vip\_hci.stats package
======================

Submodules
----------

vip\_hci.stats.bkg\_proba module
--------------------------------

.. automodule:: vip_hci.stats.bkg_proba
   :members:
   :undoc-members:
   :show-inheritance:

vip\_hci.stats.clip\_sigma module
---------------------------------

.. automodule:: vip_hci.stats.clip_sigma
   :members:
   :undoc-members:
   :show-inheritance:

vip\_hci.stats.distances module
-------------------------------

.. automodule:: vip_hci.stats.distances
   :members:
   :undoc-members:
   :show-inheritance:

vip\_hci.stats.im\_stats module
-------------------------------

.. automodule:: vip_hci.stats.im_stats
   :members:
   :undoc-members:
   :show-inheritance:

vip\_hci.stats.utils\_stats module
----------------------------------

.. automodule:: vip_hci.stats.utils_stats
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: vip_hci.stats
   :members:
   :undoc-members:
   :show-inheritance:
